pub struct InitStepSlewConfig {
pub threshold: f64,
pub hostnames: Vec<String>,
}Expand description
Configuration for the initstepslew directive.
Specifies a threshold and a list of hostnames to step the clock at chrony startup if the offset exceeds the threshold.
Fields
threshold: f64hostnames: Vec<String>Trait Implementations
Sourceimpl Clone for InitStepSlewConfig
impl Clone for InitStepSlewConfig
Sourcefn clone(&self) -> InitStepSlewConfig
fn clone(&self) -> InitStepSlewConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InitStepSlewConfig
impl Debug for InitStepSlewConfig
Sourceimpl PartialEq for InitStepSlewConfig
impl PartialEq for InitStepSlewConfig
Sourcefn eq(&self, other: &InitStepSlewConfig) -> bool
fn eq(&self, other: &InitStepSlewConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for InitStepSlewConfig