PoolBuilder

Struct PoolBuilder 

pub struct PoolBuilder { /* private fields */ }
Builder for creating pool directives.

Implementations

Source

impl PoolBuilder

pub fn new(hostname: impl Into<String>) -> Self

Creates a new builder for the given pool hostname.

All other options are initialized to chrony defaults.

pub fn iburst(self) -> Self

Enables the iburst option (initial burst of quick measurements).

pub fn burst(self) -> Self

pub fn prefer(self) -> Self

pub fn noselect(self) -> Self

pub fn trust(self) -> Self

pub fn require(self) -> Self

pub fn nts(self) -> Self

pub fn offline(self) -> Self

pub fn minpoll(self, poll: PollInterval) -> Self

pub fn maxpoll(self, poll: PollInterval) -> Self

pub fn port(self, port: UdpPort) -> Self

pub fn maxdelay(self, delay: f64) -> Self

pub fn offset(self, offset: f64) -> Self

pub fn version(self, version: NtpVersion) -> Self

pub fn key(self, key_id: u32) -> Self

pub fn minsamples(self, n: u32) -> Self

Sets the minimum number of samples to keep.

pub fn maxsamples(self, n: u32) -> Self

Sets the maximum number of samples to keep.

pub fn polltarget(self, target: PollTarget) -> Self

Sets the poll target number of samples.

pub fn maxsources(self, n: u32) -> Self

Sets the maximum number of sources from this pool.

pub fn build(self) -> Box<Directive>

Builds and returns a pool directive with the configured options.