pub struct PollInterval(/* private fields */);Expand description
A bounded integer value with range checking at construction time.
See the module-level documentation for the valid range for each type.
Implementations
Sourceimpl PollInterval
impl PollInterval
Sourcepub fn new(value: i8) -> Result<Self, ValueError>
pub fn new(value: i8) -> Result<Self, ValueError>
Creates a new value, returning an error if out of range.
Examples
use chrony_confile::values::PollInterval;
let val = PollInterval::new(6)?;
assert_eq!(val.get(), 6);
let err = PollInterval::new(100);
assert!(err.is_err());Sourcepub const fn new_unchecked(value: i8) -> Self
pub const fn new_unchecked(value: i8) -> Self
Creates a new value without bounds checking.
This is safe because an out-of-range value is not undefined behavior;
the caller is responsible for ensuring the value is within MIN..=MAX.